@@ -6,7 +6,7 @@ test_that("SI, 1G, CL: 1 sim", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0.2, act.rate = 0.25)
   init <- init.icm(s.num = 500, i.num = 1)
-  control <- control.icm(type = "SI", nsteps = 100, nsims = 1, verbose = TRUE,
+  control <- control.icm(type = "SI", nsteps = 100, nsims = 1, verbose = FALSE,
                          verbose.int = 1)
   x <- icm(param, init, control)
   expect_is(x, "icm")
@@ -30,7 +30,7 @@ test_that("SI, 1G, CL: 2 sim", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0.2, act.rate = 0.25)
   init <- init.icm(s.num = 500, i.num = 1)
-  control <- control.icm(type = "SI", nsteps = 100, nsims = 2, verbose = TRUE,
+  control <- control.icm(type = "SI", nsteps = 100, nsims = 2, verbose = FALSE,
                          verbose.int = 5)
   x <- icm(param, init, control)
   expect_is(x, "icm")
@@ -55,7 +55,7 @@ test_that("SI, 1G, CL: inf.prob = 0", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0, act.rate = 0.25)
   init <- init.icm(s.num = 500, i.num = 1)
-  control <- control.icm(type = "SI", nsteps = 25, nsims = 10, verbose = TRUE)
+  control <- control.icm(type = "SI", nsteps = 25, nsims = 10, verbose = FALSE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_true(all(x$epi$num == 501))
@@ -80,7 +80,7 @@ test_that("SI, 2G, CL: 1 sim", {
   param <- param.icm(inf.prob = 0.5, act.rate = 0.25, inf.prob.g2 = 0.1,
                      balance = "g1")
   init <- init.icm(s.num = 500, i.num = 1, s.num.g2 = 500, i.num.g2 = 0)
-  control <- control.icm(type = "SI", nsteps = 100, nsims = 1, verbose = TRUE)
+  control <- control.icm(type = "SI", nsteps = 100, nsims = 1, verbose = FALSE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_true(all(x$epi$num == 501))
@@ -103,7 +103,7 @@ test_that("SI, 2G, CL: 2 sim", {
   param <- param.icm(inf.prob = 0.2, act.rate = 0.25, inf.prob.g2 = 0.1,
                      balance = "g1")
   init <- init.icm(s.num = 500, i.num = 1, s.num.g2 = 500, i.num.g2 = 0)
-  control <- control.icm(type = "SI", nsteps = 50, nsims = 2, verbose = TRUE)
+  control <- control.icm(type = "SI", nsteps = 50, nsims = 2, verbose = FALSE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_true(all(x$epi$num == 501))
@@ -128,7 +128,7 @@ test_that("SI, 1G, OP: 1 sim", {
   param <- param.icm(inf.prob = 0.2, act.rate = 0.25,
                      b.rate = 1/100, ds.rate = 1/100, di.rate = 1/90)
   init <- init.icm(s.num = 500, i.num = 1)
-  control <- control.icm(type = "SI", nsteps = 100, nsims = 1, verbose = TRUE)
+  control <- control.icm(type = "SI", nsteps = 100, nsims = 1, verbose = FALSE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -151,7 +151,7 @@ test_that("SI, 1G, OP: 2 sim", {
   param <- param.icm(inf.prob = 0.2, act.rate = 0.25,
                      b.rate = 1/100, ds.rate = 1/100, di.rate = 1/90)
   init <- init.icm(s.num = 500, i.num = 1)
-  control <- control.icm(type = "SI", nsteps = 50, nsims = 2, verbose = TRUE)
+  control <- control.icm(type = "SI", nsteps = 50, nsims = 2, verbose = FALSE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -177,7 +177,7 @@ test_that("SI, 2G, OP: 1 sim", {
                      ds.rate = 1/100, ds.rate.g2 = 1/100,
                      di.rate = 1/90, di.rate.g2 = 1/90)
   init <- init.icm(s.num = 500, i.num = 1, s.num.g2 = 500, i.num.g2 = 0)
-  control <- control.icm(type = "SI", nsteps = 100, nsims = 1, verbose = TRUE)
+  control <- control.icm(type = "SI", nsteps = 100, nsims = 1, verbose = FALSE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -202,7 +202,7 @@ test_that("SI, 2G, OP: 2 sim", {
                      ds.rate = 1/100, ds.rate.g2 = 1/100,
                      di.rate = 1/90, di.rate.g2 = 1/90)
   init <- init.icm(s.num = 500, i.num = 1, s.num.g2 = 500, i.num.g2 = 0)
-  control <- control.icm(type = "SI", nsteps = 50, nsims = 2, verbose = TRUE,
+  control <- control.icm(type = "SI", nsteps = 50, nsims = 2, verbose = FALSE,
                          verbose.int = 5)
   x <- icm(param, init, control)
   expect_is(x, "icm")
@@ -275,7 +275,7 @@ test_that("SIR, 1G, CL: inf.prob = 0", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0, act.rate = 0.25, rec.rate = 0)
   init <- init.icm(s.num = 500, i.num = 1, r.num = 0)
-  control <- control.icm(type = "SIR", nsteps = 10, nsims = 10, verbose = TRUE)
+  control <- control.icm(type = "SIR", nsteps = 10, nsims = 10, verbose = FALSE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_equal(max(x$epi$i.num), 1)
@@ -302,7 +302,7 @@ test_that("SIR, 2G, CL: 1 sim", {
                      balance = "g1", rec.rate = 1/100, rec.rate.g2 = 1/100)
   init <- init.icm(s.num = 500, i.num = 1, r.num = 0,
                    s.num.g2 = 500, i.num.g2 = 0, r.num.g2 = 0)
-  control <- control.icm(type = "SIR", nsims = 1, nsteps = 100, verbose = TRUE)
+  control <- control.icm(type = "SIR", nsims = 1, nsteps = 100, verbose = FALSE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -326,7 +326,7 @@ test_that("SIR, 2G, CL: 2 sim", {
                      balance = "g1", rec.rate = 1/100, rec.rate.g2 = 1/100)
   init <- init.icm(s.num = 500, i.num = 1, r.num = 0,
                    s.num.g2 = 500, i.num.g2 = 0, r.num.g2 = 0)
-  control <- control.icm(type = "SIR", nsims = 2, nsteps = 50, verbose = TRUE)
+  control <- control.icm(type = "SIR", nsims = 2, nsteps = 50, verbose = FALSE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -350,7 +350,7 @@ test_that("SIR, 1G, OP: 1 sim", {
                      b.rate = 1/100, ds.rate = 1/100, di.rate = 1/90,
                      dr.rate = 1/100)
   init <- init.icm(s.num = 500, i.num = 1, r.num = 0)
-  control <- control.icm(type = "SIR", nsteps = 100, nsims = 1, verbose = TRUE)
+  control <- control.icm(type = "SIR", nsteps = 100, nsims = 1, verbose = FALSE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -374,7 +374,7 @@ test_that("SIR, 1G, OP: 2 sim", {
                      b.rate = 1/100, ds.rate = 1/100, di.rate = 1/90,
                      dr.rate = 1/100)
   init <- init.icm(s.num = 500, i.num = 1, r.num = 0)
-  control <- control.icm(type = "SIR", nsteps = 50, nsims = 2, verbose = TRUE,
+  control <- control.icm(type = "SIR", nsteps = 50, nsims = 2, verbose = FALSE,
                          d.rand = FALSE, b.rand = FALSE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
@@ -403,7 +403,7 @@ test_that("SIR, 2G, OP: 1 sim", {
                      dr.rate = 1/100, dr.rate.g2 = 1/100)
   init <- init.icm(s.num = 500, i.num = 1, r.num = 0,
                    s.num.g2 = 500, i.num.g2 = 0, r.num.g2 = 0)
-  control <- control.icm(type = "SIR", nsteps = 100, nsims = 1, verbose = TRUE,
+  control <- control.icm(type = "SIR", nsteps = 100, nsims = 1, verbose = FALSE,
                          verbose.int = 5)
   x <- icm(param, init, control)
   expect_is(x, "icm")
@@ -431,7 +431,7 @@ test_that("SIR, 2G, OP: 2 sim", {
                      dr.rate = 1/100, dr.rate.g2 = 1/100)
   init <- init.icm(s.num = 500, i.num = 1, r.num = 0,
                    s.num.g2 = 500, i.num.g2 = 0, r.num.g2 = 0)
-  control <- control.icm(type = "SIR", nsteps = 50, nsims = 2, verbose = TRUE,
+  control <- control.icm(type = "SIR", nsteps = 50, nsims = 2, verbose = FALSE,
                          verbose.int = 1, d.rand = FALSE, b.rand = FALSE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
@@ -457,7 +457,7 @@ test_that("SIS, 1G, CL: 1 sim", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0.2, act.rate = 0.25, rec.rate = 1/50)
   init <- init.icm(s.num = 500, i.num = 1)
-  control <- control.icm(type = "SIS", nsteps = 100, nsims = 1, verbose = TRUE,
+  control <- control.icm(type = "SIS", nsteps = 100, nsims = 1, verbose = FALSE,
                          verbose.int = 1)
   x <- icm(param, init, control)
   expect_equal(max(x$epi$s.num + x$epi$i.num), 501)
@@ -481,7 +481,7 @@ test_that("SIS, 1G, CL: 2 sim", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0.2, act.rate = 0.25, rec.rate = 1/50)
   init <- init.icm(s.num = 500, i.num = 1)
-  control <- control.icm(type = "SIS", nsteps = 50, nsims = 2, verbose = TRUE)
+  control <- control.icm(type = "SIS", nsteps = 50, nsims = 2, verbose = FALSE)
   x <- icm(param, init, control)
   expect_equal(max(x$epi$s.num + x$epi$i.num), 501)
   expect_is(x, "icm")
@@ -505,7 +505,7 @@ test_that("SIS, 1G, CL: inf.prob = 0", {
   skip_on_cran()
   param <- param.icm(inf.prob = 0, act.rate = 0.25, rec.rate = 0)
   init <- init.icm(s.num = 500, i.num = 1)
-  control <- control.icm(type = "SIS", nsteps = 10, nsims = 10, verbose = TRUE)
+  control <- control.icm(type = "SIS", nsteps = 10, nsims = 10, verbose = FALSE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -529,7 +529,7 @@ test_that("SIS, 2G, CL: 1 sim", {
   param <- param.icm(inf.prob = 0.2, act.rate = 0.25, inf.prob.g2 = 0.1,
                      balance = "g1", rec.rate = 1/100, rec.rate.g2 = 1/100)
   init <- init.icm(s.num = 500, i.num = 1, s.num.g2 = 500, i.num.g2 = 0)
-  control <- control.icm(type = "SIS", nsteps = 100, nsims = 1, verbose = TRUE)
+  control <- control.icm(type = "SIS", nsteps = 100, nsims = 1, verbose = FALSE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -551,7 +551,7 @@ test_that("SIS, 2G, CL: 2 sim", {
   param <- param.icm(inf.prob = 0.2, act.rate = 0.25, inf.prob.g2 = 0.1,
                      balance = "g1", rec.rate = 1/100, rec.rate.g2 = 1/100)
   init <- init.icm(s.num = 500, i.num = 1, s.num.g2 = 500, i.num.g2 = 0)
-  control <- control.icm(type = "SIS", nsteps = 50, nsims = 2, verbose = TRUE)
+  control <- control.icm(type = "SIS", nsteps = 50, nsims = 2, verbose = FALSE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -574,7 +574,7 @@ test_that("SIS, 1G, OP: 1 sim", {
   param <- param.icm(inf.prob = 0.2, act.rate = 0.5, rec.rate = 1/50,
                      b.rate = 1/100, ds.rate = 1/100, di.rate = 1/90)
   init <- init.icm(s.num = 500, i.num = 1)
-  control <- control.icm(type = "SIS", nsteps = 100, nsims = 1, verbose = TRUE)
+  control <- control.icm(type = "SIS", nsteps = 100, nsims = 1, verbose = FALSE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -597,7 +597,7 @@ test_that("SIS, 1G, OP: 2 sim", {
   param <- param.icm(inf.prob = 0.2, act.rate = 0.5, rec.rate = 1/50,
                      b.rate = 1/100, ds.rate = 1/100, di.rate = 1/90)
   init <- init.icm(s.num = 500, i.num = 1)
-  control <- control.icm(type = "SIS", nsteps = 50, nsims = 2, verbose = TRUE)
+  control <- control.icm(type = "SIS", nsteps = 50, nsims = 2, verbose = FALSE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -623,7 +623,7 @@ test_that("SIS, 2G, OP: 1 sim", {
                      b.rate = 1/100, b.rate.g2 = NA, ds.rate = 1/100,
                      ds.rate.g2 = 1/100, di.rate = 1/90, di.rate.g2 = 1/90)
   init <- init.icm(s.num = 500, i.num = 1, s.num.g2 = 500, i.num.g2 = 1)
-  control <- control.icm(type = "SIS", nsteps = 100, nsims = 1, verbose = TRUE)
+  control <- control.icm(type = "SIS", nsteps = 100, nsims = 1, verbose = FALSE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -647,7 +647,7 @@ test_that("SIS, 2G, OP: 2 sim", {
                      b.rate = 1/100, b.rate.g2 = NA, ds.rate = 1/100,
                      ds.rate.g2 = 1/100, di.rate = 1/90, di.rate.g2 = 1/90)
   init <- init.icm(s.num = 500, i.num = 1, s.num.g2 = 500, i.num.g2 = 1)
-  control <- control.icm(type = "SIS", nsteps = 50, nsims = 2, verbose = TRUE,
+  control <- control.icm(type = "SIS", nsteps = 50, nsims = 2, verbose = FALSE,
                          verbose.int = 5)
   x <- icm(param, init, control)
   expect_is(x, "icm")
