@@ -9,7 +9,7 @@ test_that("Edges only models", {
   est1 <- netest(nw, formation, target.stats, coef.diss, verbose = FALSE)
 
   ## Single simulation
-  dx1 <- netdx(est1, nsims = 1, nsteps = 10, verbose = TRUE)
+  dx1 <- netdx(est1, nsims = 1, nsteps = 10, verbose = FALSE)
   expect_is(dx1, "netdx")
   print(dx1)
   plot(dx1)
@@ -20,7 +20,7 @@ test_that("Edges only models", {
   plot(dx1, method = "b", type = "dissolution")
 
   ## Multiple simulations
-  dx2 <- netdx(est1, nsims = 2, nsteps = 10, verbose = TRUE)
+  dx2 <- netdx(est1, nsims = 2, nsteps = 10, verbose = FALSE)
   expect_is(dx2, "netdx")
   print(dx2)
   plot(dx2)
@@ -31,7 +31,7 @@ test_that("Edges only models", {
   plot(dx2, method = "b", type = "dissolution")
 
   ## Expanded monitoring formula
-  dx3 <- netdx(est1, nsims = 2, nsteps = 10, verbose = TRUE,
+  dx3 <- netdx(est1, nsims = 2, nsteps = 10, verbose = FALSE,
                nwstats.formula = ~edges + concurrent)
   expect_is(dx3, "netdx")
   print(dx3)
@@ -44,7 +44,7 @@ test_that("Edges only models", {
   plot(dx3, method = "b", type = "dissolution")
 
   ## Reduced monitoring formula
-  dx4 <- netdx(est1, nsims = 2, nsteps = 10, verbose = TRUE,
+  dx4 <- netdx(est1, nsims = 2, nsteps = 10, verbose = FALSE,
                nwstats.formula = ~meandeg)
   expect_is(dx4, "netdx")
   print(dx4)
@@ -68,7 +68,7 @@ test_that("Offset terms", {
   target.stats <- 15
   est2 <- netest(nw, formation, target.stats, coef.diss, coef.form = -Inf,
                  verbose = FALSE)
-  dx <- netdx(est2, nsims = 2, nsteps = 50, verbose = TRUE)
+  dx <- netdx(est2, nsims = 2, nsteps = 50, verbose = FALSE)
   expect_is(dx, "netdx")
   print(dx)
   plot(dx)
@@ -81,7 +81,7 @@ test_that("Offset terms", {
   rm(dx)
 
   ## Offset term with expanded formula
-  dx <- netdx(est2, nsims = 2, nsteps = 50, verbose = TRUE,
+  dx <- netdx(est2, nsims = 2, nsteps = 50, verbose = FALSE,
               nwstats.formula = ~edges + meandeg + concurrent + nodematch("loc"))
   expect_is(dx, "netdx")
   print(dx)
@@ -102,7 +102,7 @@ test_that("Faux offset term", {
   coef.diss <- dissolution_coefs(dissolution = ~offset(edges), duration = 40)
   formation <- ~edges + nodemix("loc", base = c(1, 3))
   target.stats <- c(15, 0)
-  est3 <- netest(nw, formation, target.stats, coef.diss, verbose = TRUE)
+  est3 <- netest(nw, formation, target.stats, coef.diss, verbose = FALSE)
 
   dx <- netdx(est3, nsims = 2, nsteps = 50, verbose = FALSE)
   expect_is(dx, "netdx")
@@ -140,7 +140,7 @@ test_that("Static diagnostic simulations", {
   formation <- ~edges + concurrent
   target.stats <- c(50, 20)
   coef.diss <- dissolution_coefs(dissolution = ~offset(edges), duration = 10)
-  est4 <- netest(nw, formation, target.stats, coef.diss, verbose = TRUE)
+  est4 <- netest(nw, formation, target.stats, coef.diss, verbose = FALSE)
 
   dx <- netdx(est4, dynamic = FALSE, nsims = 250,
               nwstats.formula = ~edges + meandeg + concurrent)
@@ -154,7 +154,7 @@ test_that("Static diagnostic simulations", {
 
   expect_error(plot(dx, method = "b", type = "duration"))
   expect_error(plot(dx, method = "b", type = "dissolution"))
-  
+
   # test for default formation model
   dx <- netdx(est4, dynamic = FALSE, nsims = 250, verbose = FALSE)
   expect_is(dx, "netdx")
@@ -192,7 +192,7 @@ test_that("pass in netest with sim", {
   coef.diss <- dissolution_coefs(dissolution = ~offset(edges), duration = 20)
   est1 <- netest(nw, formation, target.stats, coef.diss, output = "sim", verbose = FALSE)
   dx <- netdx(est1, nsims = 1, nsteps = 10, verbose = FALSE)
-  
+
 })
 
 test_that("Full STERGM", {
@@ -201,16 +201,16 @@ test_that("Full STERGM", {
   est <- netest(nw, formation = ~edges, target.stats = 25,
                 coef.diss = dissolution_coefs(~offset(edges), 10, 0),
                 edapprox = FALSE, verbose = FALSE)
-  
+
   # one core test
   dx <- netdx(est, nsims = 1, nsteps = 10, verbose = FALSE)
   expect_is(dx, "netdx")
   expect_true(!dx$edapprox)
   expect_true(colnames(dx$stats[[1]]) == "edges")
-  
+
   # parallel test
   dx <- netdx(est, nsims = 2, nsteps = 10, ncores = 2, verbose = FALSE)
   expect_is(dx, "netdx")
   expect_true(dx$nsims == 2)
-  
-})
\ No newline at end of file
+
+})
