@@ -4,24 +4,15 @@ test_that("network models can be restarted", {
   skip_on_cran()
 
   nw <- network.initialize(n = 100, directed = FALSE)
-  est.vit <- netest(nw,
-                    formation = ~ edges,
-                    dissolution = ~offset(edges),
-                    target.stats = 25,
+  est.vit <- netest(nw, formation = ~edges, target.stats = 25,
                     coef.diss = dissolution_coefs(~offset(edges), 10, 0.02),
                     verbose = FALSE)
 
-  param <- param.net(inf.prob = 0.5,
-                     act.rate = 2,
-                     b.rate = 0.02,
-                     ds.rate = 0.02,
-                     di.rate = 0.02)
+  param <- param.net(inf.prob = 0.5, act.rate = 2, b.rate = 0.02,
+                     ds.rate = 0.02, di.rate = 0.02)
   init <- init.net(i.num = 10)
-  control <- control.net(type = "SI", nsteps = 5,
-                         nsims = 1,
-                         verbose = FALSE,
-                         tea.status = FALSE,
-                         save.other = "attr")
+  control <- control.net(type = "SI", nsteps = 5, nsims = 1,
+                         verbose = FALSE, tea.status = FALSE, save.other = "attr")
   x <- netsim(est.vit, param, init, control)
 
   control <- control.net(type = "SI", nsteps = 10, start = 6,
@@ -43,18 +34,12 @@ test_that("restart error flags", {
   skip_on_cran()
 
   nw <- network.initialize(n = 100, directed = FALSE)
-  est.vit <- netest(nw,
-                    formation = ~ edges,
-                    dissolution = ~offset(edges),
-                    target.stats = 25,
+  est.vit <- netest(nw, formation = ~edges, target.stats = 25,
                     coef.diss = dissolution_coefs(~offset(edges), 10, 0.02),
                     verbose = FALSE)
 
-  param <- param.net(inf.prob = 0.5,
-                     act.rate = 2,
-                     b.rate = 0.02,
-                     ds.rate = 0.02,
-                     di.rate = 0.02)
+  param <- param.net(inf.prob = 0.5, act.rate = 2, b.rate = 0.02,
+                     ds.rate = 0.02, di.rate = 0.02)
   init <- init.net(i.num = 10)
   control <- control.net(type = "SI", nsteps = 5,
                          nsims = 1,
